Archived attention backend snapshots.

These files are kept only for code harvesting and historical reference.
They are intentionally stored as `.py.txt` snapshots so they are not part of
the importable Python package and are not expected to compile or run.
